*******************************************************
* Load data
*******************************************************

// Load data on lambdas and merge with HHIs

use "$path_temp/lambda_inter", clear
merge 1:1 fyear using "$path_temp/lambda_intra"
replace fyear = fyear+1
drop _m

merge 1:1 fyear using "$inputs/hhis_compustat_emp"
drop _m
merge 1:1 fyear using "$inputs/hhis_compustat"
drop _m

keep if fyear>=1985 & fyear<=2017

// Adjust lambdas for share of private companies in the economy
gen private_share = 0.587

gen lambda_inter_ = lambda_inter*(1-private_share)^2
gen lambda_intra_ = lambda_intra*(1-private_share)^2

gen mhhi = hhi + lambda_intra_*(1-hhi)
gen mhhi_labor = hhi_labor + lambda_intra_*(1-hhi_labor)

// Define elasticity parameters

gen eta = 0.59
gen nsectors = 453
gen theta = 3/(1-1/nsectors)


*******************************************************
* Calculate implied markup
*******************************************************

gen mu_labor = mhhi_labor/eta
gen mu_product = (mhhi-lambda_inter_)/theta
gen one_plus_mu = (1+mu_labor)/(1-mu_product)
gen markup_model = one_plus_mu
gen markup_ab = 1-1/one_plus_mu

gen eff_labor = 1/hhi_labor
gen eff = 1/hhi
gen eff_labor_mhhi = 1/mhhi_labor
gen eff_mhhi = 1/mhhi

list fyear lambda_inter lambda_intra lambda_inter_ lambda_intra_ hhi hhi_labor mhhi mhhi_labor eff* markup_model markup_ab if inlist(fyear,1985,2017)
