*********************************
* Lambdas
*********************************

set more off
set type double

// Prepare ownership data

use "$inputs/thomson/thomson_data.dta", clear

keep if month(rdate)==12
drop if cusip==""
keep if inlist(stkcd,"0"," ","")
drop if inlist(exchcd,"I","J","K","W","Z")

gen year = year(rdate)


* keep the latest filed report
bys cusip mgrno rdate: egen maxfdate = max(fdate)
keep if fdate == maxfdate
drop maxfdate
drop prc

rename cusip ncusip
rename exchcd exchcd_thomson
merge m:1 ncusip year using "$inputs/crsp_yearly"
keep if _m==3
drop _m

gen mkt_cap = prc*shrout
drop if mkt_cap==.

// merge in the fixed mgrnos
gen mgrname_clean = subinstr(mgrname," ","",.)
foreach s in & ' ( ) * + , - . / _ {
	replace mgrname_clean = subinstr(mgrname_clean,"`s'","",.)
}
gen mgrno_original = mgrno
merge m:1 mgrno_original mgrname_clean using "$inputs\mgrno cleaned.dta"
keep if _m!=2
drop _merge
replace mgrno = mgrno_new if mgrno_new!=.

drop mgrname_clean 

replace no = 0 if no==.

gen beta = shares/(1000*shrout)
gen gamma = (shares-no) /(shrout*1000)

drop if beta==. | gamma==.



collapse (sum) beta gamma (mean) mkt_cap, by(ncusip cusip permco permno siccd mgrno year rdate)


drop if mkt_cap<=0
gen nmkt_cap = -mkt_cap
sort rdate permco nmkt_cap permno
by rdate permco nmkt_cap permno: gen N = _n==1
by rdate permco: gen rank = sum(N)
keep if rank==1

drop N rank
sort rdate permco mgrno

// Select largest 1500 firms from the ownership data and drop very small holdings
sort rdate nmkt_cap permco
by rdate nmkt_cap permco: gen N = _n==1
by rdate: gen rank = sum(N)
keep if rank<=1500
drop if beta<=0.001
drop if sic >= 4900 & sic <= 4999			// regulated utilities
drop if sic >= 6000 & sic <= 6799			// financials and RE
keep mgrno permco beta gamma rdate siccd mkt_cap

compress
save "$path_temp/ownership_1500", replace

local k = 1
local quarter = 4

forvalues year = 1984/2017 {

disp "*******************"
disp "Year: `year'"
disp "Quarter: `quarter'"
disp "*******************"


use "$path_temp/ownership_1500", clear

keep if year(rdate)==`year' & quarter(rdate)==`quarter'
drop rdate

rename * *1
rename mgrno1 mgrno
sort permco1
by permco1: gen N = _n==1
egen mkt_cap_total = total(N*mkt_cap1)
replace mkt_cap1 = mkt_cap1/mkt_cap_total
drop N mkt_cap_total
save "$path_temp/temp", replace
rename *1 *2
drop gamma2
save "$path_temp/temp2", replace

// Create list of firms to pair with
use "$path_temp/temp", clear
keep permco1
rename permco1 permco2
duplicates drop
save "$path_temp/permco2", replace

// Create data at the firm-pair-mgrno level and calculate lambdas
use "$path_temp/temp", clear
sort permco1
by permco1: egen g1b1=sum( gamma1* beta1 )
cross using "$path_temp/permco2"
drop if permco1==permco2
merge m:1 mgrno permco2 using "$path_temp/temp2", keep(3) nogen
sort permco1 permco2
by permco1 permco2: egen g1b2=sum( gamma1* beta2 )
gen lambda = g1b2/g1b1
drop if mkt_cap1==. | mkt_cap2==.
sort permco1 permco2 mgrno
by permco1 permco2: keep if _n==1
gen w = mkt_cap1* mkt_cap2

keep permco1 permco2 mkt_cap1 mkt_cap2 siccd1 siccd2 lambda w

gen year = `year'
gen yq = yq(`year',`quarter')
format yq %tq

if `k'>1 append using "$path_temp/lambdas_firm_pair"
save "$path_temp/lambdas_firm_pair", replace

local k = 2
}


// Calculate lambda intra

preserve
use "$path_temp/lambdas_firm_pair", clear
keep if siccd1==siccd2
replace lambda = 1.5 if lambda>=1.5
collapse (mean) lambda [aw=w], by(year)
rename lambda lambda_intra
rename year fyear
save "$path_temp/lambda_intra", replace
restore

// Calculate lambda inter

preserve
use "$path_temp/lambdas_firm_pair", clear
keep if siccd1!=siccd2
replace lambda = 1.5 if lambda>=1.5
collapse (mean) lambda [aw=w], by(year)
rename lambda lambda_inter
rename year fyear
save "$path_temp/lambda_inter", replace
restore
